"use client"

import { useState } from "react"
import { motion } from "framer-motion"
import { Button } from "@/components/ui/button"
import { ArrowRight, Brain, Sparkles } from "lucide-react"
import LanguageSwitcher from "./LanguageSwitcher"
import Image from "next/image"

export default function Hero() {
  const [currentLanguage, setCurrentLanguage] = useState<"tr" | "en">("tr")

  return (
    <section className="relative overflow-hidden py-20 md:py-32">
      <div className="absolute top-0 right-0 w-full h-full overflow-hidden z-0">
        <div className="absolute top-0 right-0 w-[800px] h-[800px] bg-primary/10 rounded-full blur-3xl opacity-20 -translate-y-1/2 translate-x-1/2"></div>
        <div className="absolute bottom-0 left-0 w-[600px] h-[600px] bg-accent/10 rounded-full blur-3xl opacity-20 translate-y-1/2 -translate-x-1/2"></div>
      </div>

      <div className="container relative z-10">
        <div className="absolute top-0 right-0">
          <LanguageSwitcher
            currentLanguage={currentLanguage}
            onLanguageChange={(lang) => setCurrentLanguage(lang as "tr" | "en")}
          />
        </div>

        <div className="flex flex-col items-center text-center">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5 }}
            className="flex items-center gap-2 mb-6 glass-effect px-4 py-2 rounded-full"
          >
            <Sparkles className="h-5 w-5 text-primary animate-pulse-glow" />
            <span className="text-sm font-medium text-primary">
              {currentLanguage === "tr" ? "Yapay Zeka Destekli Dijital Pazarlama" : "AI-Powered Digital Marketing"}
            </span>
          </motion.div>

          <motion.h1
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5, delay: 0.1 }}
            className="text-5xl md:text-7xl font-bold tracking-tight mb-6 golden-text golden-glow"
          >
            Anamur AI
          </motion.h1>

          <motion.p
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5, delay: 0.2 }}
            className="text-xl md:text-2xl text-muted-foreground max-w-3xl mb-10"
          >
            {currentLanguage === "tr"
              ? "Global ölçekte yapay zeka destekli dijital pazarlama çözümleri ile işletmenizi geleceğe taşıyın."
              : "Take your business to the future with AI-powered digital marketing solutions on a global scale."}
          </motion.p>

          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5, delay: 0.3 }}
            className="flex flex-col sm:flex-row gap-4"
          >
            <Button size="lg" className="group bg-primary hover:bg-primary/90 text-white animated-border">
              {currentLanguage === "tr" ? "Hizmetlerimizi Keşfedin" : "Explore Our Services"}
              <ArrowRight className="ml-2 h-4 w-4 transition-transform group-hover:translate-x-1" />
            </Button>
            <Button size="lg" variant="outline" className="border-primary/20 hover:border-primary/40 text-primary">
              {currentLanguage === "tr" ? "İletişime Geçin" : "Contact Us"}
            </Button>
          </motion.div>
        </div>

        <motion.div
          initial={{ opacity: 0, scale: 0.9 }}
          animate={{ opacity: 1, scale: 1 }}
          transition={{ duration: 0.8, delay: 0.5 }}
          className="mt-16 relative mx-auto max-w-4xl"
        >
          <div className="aspect-video rounded-xl overflow-hidden glass-card neon-border">
            <div className="relative w-full h-full">
              <Image
                src="/placeholder.svg?height=600&width=1200"
                alt="AI Technology Visualization"
                fill
                className="object-cover opacity-40"
              />
              <div className="absolute inset-0 flex items-center justify-center">
                <div className="text-center p-8 z-10">
                  <div className="w-24 h-24 mx-auto mb-6 rounded-full bg-amber-500/10 flex items-center justify-center border border-amber-500/30 golden-border">
                    <Brain className="h-12 w-12 text-amber-400 golden-neon-glow" />
                  </div>
                  <h3 className="text-2xl font-bold mb-2 text-glow">
                    {currentLanguage === "tr" ? "Yapay Zeka Teknolojisi" : "Artificial Intelligence Technology"}
                  </h3>
                  <p className="text-muted-foreground">
                    {currentLanguage === "tr"
                      ? "Dijital pazarlama stratejilerinizi yapay zeka ile güçlendirin."
                      : "Empower your digital marketing strategies with artificial intelligence."}
                  </p>
                </div>
              </div>
            </div>
          </div>
        </motion.div>
      </div>
    </section>
  )
}

